@@ -1,4 +1,7 @@
-class end_script():
+from typing_extensions import Self
+
+
+class end_script(Self):
     def end(self):
         while True:
             for event in pygame.event.get():
