@@ -1,4 +1,7 @@
-class start_script():
+from typing_extensions import Self
+
+
+class start_script(Self):
     def starting(self):
         pygame.init()
         clock = pygame.time.Clock()
